"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const fs_1 = require("fs");
const reporter_1 = require("./reporter");
/**
 * Creates a new reporter to be used in the globals.js file.
 */
function createReporter(options) {
    return (results, callback) => write(results, options, callback);
}
exports.createReporter = createReporter;
/**
 * A convenience reporter function.
 */
function reporter(results, callback) {
    const nwJsonPath = path_1.resolve(process.cwd(), 'nightwatch.json');
    const options = {};
    if (fs_1.existsSync(nwJsonPath)) {
        const nwJson = JSON.parse(fs_1.readFileSync(nwJsonPath, 'utf8'));
        options.output_folder = path_1.join(nwJson.output_folder || '', 'nunit3');
    }
    write(results, options, callback);
}
exports.reporter = reporter;
/**
 * Standard CLI interface as defined by Nightwatch.js.
 */
function write(results, options, callback) {
    const reporter = new reporter_1.NUnit3Reporter(results, options);
    reporter.write().then(() => callback(), err => {
        console.error(err);
        callback(err);
    });
}
exports.write = write;
