"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ejs = require("ejs");
const template_1 = require("./template");
const fs_1 = require("fs");
const path_1 = require("path");
const utils_1 = require("./utils");
class NUnit3Reporter {
    constructor(results, opts = {}) {
        this.results = results;
        this.options = opts;
    }
    adaptAssertions(module) {
        Object.keys(module.completed).forEach(item => {
            const testcase = module.completed[item];
            const assertions = testcase.assertions;
            for (let i = 0; i < assertions.length; i++) {
                if (assertions[i].stackTrace) {
                    assertions[i].stackTrace = utils_1.stackTraceFilter(assertions[i].stackTrace.split('\n'));
                }
            }
            if (testcase.failed > 0 && testcase.stackTrace) {
                const stackParts = testcase.stackTrace.split('\n');
                const errorMessage = stackParts.shift();
                testcase.stackTrace = utils_1.stackTraceFilter(stackParts);
                testcase.message = errorMessage;
            }
        });
    }
    writeReportFile(filename, rendered, shouldCreateFolder, output_folder) {
        const promise = shouldCreateFolder ? utils_1.createReportFolder(output_folder) : Promise.resolve();
        return promise.then(() => {
            return new Promise((resolve, reject) => {
                fs_1.writeFile(filename, rendered, err => (err ? reject(err) : resolve()));
            });
        });
    }
    writeReport(moduleKey, data) {
        const currentModule = this.results.modules[moduleKey];
        const pathParts = moduleKey.split(path_1.sep);
        const moduleName = pathParts.pop();
        let className = moduleName;
        let output_folder = this.options.output_folder || '';
        let shouldCreateFolder = false;
        this.adaptAssertions(currentModule);
        if (pathParts.length) {
            output_folder = path_1.join(output_folder, pathParts.join(path_1.sep));
            className = `${pathParts.join('.')}.${moduleName}`;
            shouldCreateFolder = true;
        }
        const filename = path_1.join(output_folder, `${currentModule.reportPrefix}${moduleName}.xml`);
        const systemerr = this.results.errmessages.join('\n');
        const rendered = utils_1.stripControlChars(ejs.render(data, {
            module: currentModule,
            moduleName: moduleName,
            className: className,
            systemerr,
        }));
        return this.writeReportFile(filename, rendered, shouldCreateFolder, output_folder);
    }
    write() {
        const keys = Object.keys(this.results.modules);
        return template_1.loadTemplate().then(data => {
            const promises = keys.map(moduleKey => this.writeReport(moduleKey, data));
            return Promise.all(promises);
        });
    }
}
exports.NUnit3Reporter = NUnit3Reporter;
